summaryrefslogtreecommitdiffstats
path: root/base/file_util_proxy.h
diff options
context:
space:
mode:
authordumi@chromium.org <dumi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-08-24 20:26:23 +0000
committerdumi@chromium.org <dumi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-08-24 20:26:23 +0000
commitd480a3ecadc882225c2b249346dae3759e3f8fce (patch)
treed55e2570388f613e295daf34454bb40c2b787d99 /base/file_util_proxy.h
parent27dff5f0003a845b99e1718771ebf29b04cff0a6 (diff)
downloadchromium_src-d480a3ecadc882225c2b249346dae3759e3f8fce.zip
chromium_src-d480a3ecadc882225c2b249346dae3759e3f8fce.tar.gz
chromium_src-d480a3ecadc882225c2b249346dae3759e3f8fce.tar.bz2
Change the FileUtilProxy callbacks to report error codes instead of booleans.
BUG=none TEST=none Review URL: http://codereview.chromium.org/3165050 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@57228 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'base/file_util_proxy.h')
-rw-r--r--base/file_util_proxy.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/base/file_util_proxy.h b/base/file_util_proxy.h
index cd6b158..87cd081 100644
--- a/base/file_util_proxy.h
+++ b/base/file_util_proxy.h
@@ -17,40 +17,40 @@ class MessageLoopProxy;
// This class provides asynchronous access to common file routines.
class FileUtilProxy {
public:
// This callback is used by methods that report success with a bool. It is
// valid to pass NULL as the callback parameter to any function that takes a
// StatusCallback, in which case the operation will complete silently.
- typedef Callback1<bool /* succeeded */>::Type StatusCallback;
+ typedef Callback1<int /* error code */>::Type StatusCallback;
// Creates or opens a file with the given flags. It is invalid to pass NULL
// for the callback.
- typedef Callback2<base::PassPlatformFile, bool /* created */>::Type
- CreateOrOpenCallback;
- static void CreateOrOpen(scoped_refptr<MessageLoopProxy> message_loop_proxy,
+ typedef Callback3<int /* error code */, base::PassPlatformFile,
+ bool /* created */>::Type CreateOrOpenCallback;
+ static bool CreateOrOpen(scoped_refptr<MessageLoopProxy> message_loop_proxy,
const FilePath& file_path,
int file_flags,
CreateOrOpenCallback* callback);
// Creates a temporary file for writing. The path and an open file handle
// are returned. It is invalid to pass NULL for the callback.
- typedef Callback2<base::PassPlatformFile, FilePath>::Type
- CreateTemporaryCallback;
- static void CreateTemporary(
+ typedef Callback3<int /* error code */, base::PassPlatformFile,
+ FilePath>::Type CreateTemporaryCallback;
+ static bool CreateTemporary(
scoped_refptr<MessageLoopProxy> message_loop_proxy,
CreateTemporaryCallback* callback);
// Close the given file handle.
- static void Close(scoped_refptr<MessageLoopProxy> message_loop_proxy,
+ static bool Close(scoped_refptr<MessageLoopProxy> message_loop_proxy,
base::PlatformFile,
StatusCallback* callback);
// Deletes a file or empty directory.
- static void Delete(scoped_refptr<MessageLoopProxy> message_loop_proxy,
+ static bool Delete(scoped_refptr<MessageLoopProxy> message_loop_proxy,
const FilePath& file_path,
StatusCallback* callback);
// Deletes a directory and all of its contents.
- static void RecursiveDelete(
+ static bool RecursiveDelete(
scoped_refptr<MessageLoopProxy> message_loop_proxy,
const FilePath& file_path,
StatusCallback* callback);
@@ -17,40 +17,40 @@ class MessageLoopProxy;
class FileUtilProxy {
public:
- // This callback is used by methods that report success with a bool. It is
+ // This callback is used by methods that report only an error code. It is
// valid to pass NULL as the callback parameter to any function that takes a
// StatusCallback, in which case the operation will complete silently.